@@ -10,8 +10,10 @@ test_that("TESTS (1/4)", {
 	Owide <- superbToWide(Orange, id = "Tree", WSFactors = "age", variable = "DV" )
 
     expect_output( str(Owide), "data.frame")
-    expect_equal( Owide$DV.118[1], 30)
-    expect_equal( Owide$DV.1582[5], 177)
+    expect_equal( Owide$DV.118[Owide$Tree[1]], 
+        dplyr::filter(Orange, Tree == Owide$Tree[1]& age == 118)$DV)
+    expect_equal( Owide$DV.1582[Owide$Tree[5]], 
+            dplyr::filter(Orange, Tree == Owide$Tree[5]& age == 1582)$DV)
 
     # restores default information
     options("superb.feedback" = c('design','warnings','summary'))
@@ -55,7 +57,7 @@ test_that("TESTS (3/4)", {
     options("superb.feedback" = c('design','warnings','summary'))
 })
 
-test_that("TESTS (3/4)", {
+test_that("TESTS (4/4)", {
 	old <- options() 
 	on.exit(options(old)) 
     options("superb.feedback" = 'none')
@@ -72,3 +74,43 @@ test_that("TESTS (3/4)", {
     # restores default information
     options("superb.feedback" = c('design','warnings','summary'))
 })
+
+test_that("TESTS (5/4...)", {
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
+    #### emulate within-subject dataset
+    dta <- GRD( 
+        BSFactors = c("Factor(4)","Replication(2)"),
+        Population = list( mean = 100, stddev = 15),
+        Effects = list( Factor = extent(10) )
+    )
+    dta$id <- ((dta$id-1) %% 100)+1
+
+    # works ok as replication is taken into account
+    superb( DV ~ Factor + Replication  | id,
+        dta,
+        adjustments = list (decorrelation = 'none', purpose = 'difference'),
+        errorbar = 'CI',
+        plotLayout = 'line',
+        errorbarParams = list (linewidth = 0.5, color = 'black'),
+        pointParams = list (size = 3, color = 'black')
+       ) + theme_bw()
+
+    # should return a message as replication is left unspecified
+    expect_message( superb( DV ~ Factor  | id,
+        dta,
+        adjustments = list (decorrelation = 'none', purpose = 'difference'),
+        errorbar = 'CI',
+        plotLayout = 'line',
+        errorbarParams = list (linewidth = 0.5, color = 'black'),
+        pointParams = list (size = 3, color = 'black')
+       ) + theme_bw() )
+
+
+    # restores default information
+    options("superb.feedback" = c('design','warnings','summary'))
+})
+
+
